@@ -30,8 +30,11 @@ sub resolve_sockaddr : prototype($$$$$$) ( $node, $service, $proto, $family, $ty
 
     if ( $node eq 'unix/' ) {
 
-        # error
-        return $cb->() if $family || $service !~ /^[\/\x00]/sm;
+        # error, socket path must be absolute
+        return $cb->() if $family || substr( $service, 0, 1 ) ne '/';
+
+        # UDS socket
+        substr $service, 0, 1, '' if substr( $service, 0, 2 ) eq "/\x00";
 
         return $cb->( [ AF_UNIX, defined $type ? $type : SOCK_STREAM, 0, Socket::pack_sockaddr_un $service] );
     }
@@ -81,7 +84,9 @@ sub resolve_sockaddr : prototype($$$$$$) ( $node, $service, $proto, $family, $ty
 sub _tcp_bind : prototype($$$;$) ( $host, $service, $done, $prepare = undef ) {
 
     # hook for Linux abstract Unix Domain Sockets (UDS)
-    if ( defined $host && $host eq 'unix/' && substr( $service, 0, 1 ) eq "\x00" ) {
+    if ( defined $host && $host eq 'unix/' && substr( $service, 0, 2 ) eq "/\x00" ) {
+        substr $service, 0, 1, '';
+
         state $ipn_uds = pack 'S', AF_UNIX;
 
         my %state;
@@ -117,9 +122,11 @@ sub _tcp_bind : prototype($$$;$) ( $host, $service, $done, $prepare = undef ) {
 ## |======+======================+================================================================================================================|
 ## |    3 | 16, 23               | Variables::ProtectPrivateVars - Private variable used                                                          |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 108                  | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
+## |    3 | 113                  | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 84                   | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
+## |    2 | 37, 88               | ValuesAndExpressions::ProhibitEmptyQuotes - Quotes used with a string containing no non-whitespace characters  |
+## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
+## |    2 | 37, 87               | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
