@@ -1,17 +1,20 @@
 package Pcore::CDN::Bucket;
 
 use Pcore -role;
+use Pcore::Util::UUID qw[uuid_v1mc_str];
 use overload '&{}' => sub ( $self, @ ) {
     return sub { $self->get_url(@_) }
   },
   fallback => 1;
 
-requires qw[get_nginx_cfg];
+requires qw[upload];
 
-has prefix => ( init_arg => undef );
+has id => sub {uuid_v1mc_str}, init_arg => undef;
 
 sub get_url ( $self, $path ) { return $self->{prefix} . $path }
 
+sub get_nginx_cfg ($self) {return}
+
 1;
 __END__
 =pod
